@@ -6,10 +6,6 @@ from datetime import date
 from cfonb.writer import transfert as w
 
 
-def _print(res):
-    print(res.replace('\r\n','\\r\\n').replace(' ','.'))
-
-
 class TestTransfert(unittest.TestCase):
 
     def test_empty_file(self):
@@ -17,7 +13,9 @@ class TestTransfert(unittest.TestCase):
         a = w.Transfert()
         a.setEmeteurInfos('2000121','bigbrother','virement de test',503103,2313033,1212,d)
         res = a.render()
-        want = '0302        200012       14101bigbrother              viremen                   E     503102313033                                                   1212       \r\n0802        200012                                                                                    0000000000000000                                          \r\n'
+        want = '''0302        200012       141011bigbrother              viremen                   E     503102313033                                                   1212       
+0802        200012                                                                                    0000000000000000                                          
+'''
         assert res == want
 
     def test_one_line(self):
@@ -26,9 +24,10 @@ class TestTransfert(unittest.TestCase):
         a.setEmeteurInfos('2000121','bigbrother','virement de test',503103,2313033,1212,d)
         a.add('un test','littlebrother','credit agricole ile de france',50011,6565329000,100,'un peu d\'argent',6335)
         res = a.render()
-        want = '0302        200012       14101bigbrother              viremen                   E     503102313033                                                   1212       \r\n0602        200012un test     littlebrother           credit agricole ile de f        50011656530000000000010000un peu d\'argent                6335       \r\n0802        200012                                                                                    0000000000010000                                          \r\n'
-        # _print(res)
-        # _print(want)
+        want = '''0302        200012       141011bigbrother              viremen                   E     503102313033                                                   1212       
+0602        200012un test     littlebrother           credit agricole ile de f        50011656530000000000010000un peu d'argent                6335       
+0802        200012                                                                                    0000000000010000                                          
+'''
         assert res == want
 
 
